Crate outgauge

Crate outgauge 

A friendly, Rust idiomatic library for the Outgauge protocol used by Live for Speed racing simulator.

The focus of this library is providing a high level, strongly typed, primitives that are difficult to misuse and have reasonable performance, rather than be a thin layer over a series of bytes.

Where possible this crate aligns the naming of fields in packets to match the original Outgauge specification.

High-level features

  • “sans-io” implementation of Outgauge

You might also find these related crates useful:

  • insim - for interacting with LFS over Insim
  • insim_pth – for reading and writing LFS PTH files
  • insim_smx – for reading and writing LFS SMX files
  • outsim - “sans-io” implementation of the LFS outsim protocol

They follow the same design focus and can be found in the same GitHub repository.

Examples

Examples can be found in the GitHub repository.

Re-exports

pub use ::insim_core as core;

Structs

Outgauge
Outgauge packet
OutgaugeFlags
Describes the setup of a player and the various helpers that may be enabled, such as auto-clutch, etc.
OutgaugeId
Unique Player Identifier, commonly referred to as PLID in Insim.txt
OutgaugeSpeed
Outgauge speed kind